summary refs log tree commit diff
path: root/src/libstd/path
diff options
context:
space:
mode:
authorHuon Wilson <dbau.pp+github@gmail.com>2014-01-30 00:46:37 +1100
committerHuon Wilson <dbau.pp+github@gmail.com>2014-02-02 12:55:15 +1100
commit003ce502350ed1e374b740ee2d719e500c165615 (patch)
treee253c6227b70a139539529bbdbb4d348cb1f64c3 /src/libstd/path
parent2bcd951749b67402ccaa31f1bb0349656f880fe2 (diff)
downloadrust-003ce502350ed1e374b740ee2d719e500c165615.tar.gz
rust-003ce502350ed1e374b740ee2d719e500c165615.zip
std: rename fmt::Default to `Show`.
This is a better name with which to have a #[deriving] mode.

Decision in:
https://github.com/mozilla/rust/wiki/Meeting-weekly-2014-01-28
Diffstat (limited to 'src/libstd/path')
-rw-r--r--src/libstd/path/mod.rs6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/libstd/path/mod.rs b/src/libstd/path/mod.rs
index c5482811a94..86f96a1075b 100644
--- a/src/libstd/path/mod.rs
+++ b/src/libstd/path/mod.rs
@@ -198,14 +198,14 @@ pub trait GenericPath: Clone + GenericPathUnsafe {
     /// Converts the Path into an owned byte vector
     fn into_vec(self) -> ~[u8];
 
     /// Returns an object that implements `fmt::Default` for printing paths
     ///
     /// This will print the equivalent of `to_display_str()` when used with a {} format parameter.
     fn display<'a>(&'a self) -> Display<'a, Self> {
         Display{ path: self, filename: false }
     }
 
     /// Returns an object that implements `fmt::Default` for printing filenames
     ///
     /// This will print the equivalent of `to_filename_display_str()` when used with a {}
     /// format parameter. If there is no filename, nothing will be printed.
@@ -532,7 +532,7 @@ pub struct Display<'a, P> {
     priv filename: bool
 }
 
-impl<'a, P: GenericPath> fmt::Default for Display<'a, P> {
+impl<'a, P: GenericPath> fmt::Show for Display<'a, P> {
     fn fmt(d: &Display<P>, f: &mut fmt::Formatter) {
         d.with_str(|s| f.pad(s))
     }
@@ -198,14 +198,14 @@ pub trait GenericPath: Clone + GenericPathUnsafe {
     fn into_vec(self) -> ~[u8];
 
-    /// Returns an object that implements `fmt::Default` for printing paths
+    /// Returns an object that implements `Show` for printing paths
     ///
     /// This will print the equivalent of `to_display_str()` when used with a {} format parameter.
@@ -198,14 +198,14 @@ pub trait GenericPath: Clone + GenericPathUnsafe {
     }
 
-    /// Returns an object that implements `fmt::Default` for printing filenames
+    /// Returns an object that implements `Show` for printing filenames
     ///
     /// This will print the equivalent of `to_filename_display_str()` when used with a {}